@@ -8,9 +8,6 @@ use Apache2::Const qw(
                        :common :http 
                        );
 
-use Apache2::REST::Conf ;
-use Apache2::REST::ErrorOutputRegistry ;
-
 use base qw/Class::AutoAccess/ ;
 
 =head1 NAME
@@ -73,8 +70,6 @@ sub handle{
         ## Check auth first
         if ( $self->isAuth($method , $req )){
             unless( $self->can($method)){
-                $resp->message('Method '.$method.' not implemented');
-                $resp->status(HTTP_NOT_IMPLEMENTED);
                 return HTTP_NOT_IMPLEMENTED ;
             }
             my $res = undef;
@@ -82,18 +77,16 @@ sub handle{
                 $res = $self->$method($req,$resp) ;
             };
             if ( $@ ){
-                my $err = $@ ;
-                Apache2::REST::ErrorOutputRegistry->instance()->getOutput($self->conf()->Apache2RESTErrorOutput())->handle($err,$resp, $req);
-                
                 $resp->status(HTTP_INTERNAL_SERVER_ERROR);
+                $resp->message('SERVER ERROR: '.$@);
                 return HTTP_INTERNAL_SERVER_ERROR ;
             }
             $resp->status($res) ;
             return $res ;
         }else{
-            $resp->status(HTTP_UNAUTHORIZED) ;
-            $resp->message('method unauthorized') ;
-            return HTTP_UNAUTHORIZED ;
+            $resp->status(HTTP_METHOD_NOT_ALLOWED) ;
+            $resp->message('method not allowed') ;
+            return HTTP_METHOD_NOT_ALLOWED ;
         }
     }
     my $fragment = shift @$stack ;
@@ -173,34 +166,13 @@ You can override this in subclasses. Do not forget to call $class->SUPER::new()
 =cut
 
 sub new{
-    my ( $class , $parent ) = @_ ;
+    my ( $class , $parent) = @_ ;
     my $self = {
         'parent' => $parent ,
     };
-    # Enforce the presence of the _conf attribute.
-    if ( $parent ){
-        $self->{'_conf'} = $parent->conf() ;
-    }else{
-        $self->{'_conf'} = Apache2::REST::Conf->new()  ;
-    }
     return bless $self , $class ;
 }
 
-=head2 conf
-
-Get/Sets the configuration attached to this handler.
-Or the parent one if no one is defined.
-
-=cut
-
-sub conf{
-    my ( $self , $newC ) = @_ ;
-    if ( defined $newC ){
-        $self->{'_conf'} = $newC ;
-    }
-    return $self->{'_conf'} || $self->parent()->conf() ;
-}
-
 =head2 isTopLevel
 
 Returns true if this handler handles the application top level.
