@@ -22,21 +22,11 @@ Apache2::REST::Handler::test - test handler access '/test/' to test your install
 sub GET{
     my ($self, $req , $resp ) = @_ ;
     
-    if ( $req->param('die') ){
-        die "This is an error\n" ;
-    }
-    
     $resp->data()->{'test_mess'} = 'This is a GET test message' ;
     ## It is OK
     return Apache2::Const::HTTP_OK ;
 }
 
-=head2 POST
-
-Performs a fake POST
-
-=cut
-
 sub POST{
     my ($self, $req , $resp ) = @_ ;
     $resp->data()->{'test_mess'} = 'This is a POST test message' ;
@@ -44,25 +34,12 @@ sub POST{
     return Apache2::Const::HTTP_OK ;
 }
 
-=head2 PUT
-
-Performs a fake PUT
-
-=cut
-
 sub PUT{
     my ($self, $req , $resp ) = @_ ;
     $resp->data()->{'test_mess'} = 'This is a PUT test message' ;
     ## It is OK
     return Apache2::Const::HTTP_OK ;
 }
-
-=head2 DELETE
-
-Performs a fake DELETE
-
-=cut
-
 sub DELETE{
     my ($self, $req , $resp ) = @_ ;
     $resp->data()->{'test_mess'} = 'This is a DELETE test message' ;
@@ -71,6 +48,8 @@ sub DELETE{
 }
 
 
+
+
 =head2 buildNext
 
 Builds a new test::user using the fragment after C<test/>.
